@@ -62,20 +62,20 @@ int wkt_lexer_read_srid(char *str)
 {
 	char *c = str;
 	long i = 0;
-	int srid;
+	int32_t srid;
 
 	if( ! str ) return SRID_UNKNOWN;
 	c += 5; /* Advance past "SRID=" */
 	i = strtol(c, NULL, 10);
-	srid = clamp_srid((int)i);
+	srid = clamp_srid((int32_t)i);
 	/* TODO: warn on explicit UNKNOWN srid ? */
 	return srid;
 }
 
-static uint8_t wkt_dimensionality(char *dimensionality)
+static lwflags_t wkt_dimensionality(char *dimensionality)
 {
-	int i = 0;
-	uint8_t flags = 0;
+	size_t i = 0;
+	lwflags_t flags = 0;
 
 	if( ! dimensionality )
 		return flags;
@@ -98,11 +98,11 @@ static uint8_t wkt_dimensionality(char *dimensionality)
 * Force the dimensionality of a geometry to match the dimensionality
 * of a set of flags (usually derived from a ZM WKT tag).
 */
-static int wkt_parser_set_dims(LWGEOM *geom, uint8_t flags)
+static int wkt_parser_set_dims(LWGEOM *geom, lwflags_t flags)
 {
 	int hasz = FLAGS_GET_Z(flags);
 	int hasm = FLAGS_GET_M(flags);
-	int i = 0;
+	uint32_t i = 0;
 
 	/* Error on junk */
 	if( ! geom )
@@ -180,7 +180,7 @@ static int wkt_parser_set_dims(LWGEOM *geom, uint8_t flags)
 * dimensionality matches that of the pointarray. If the dimension counts
 * match, ensure the pointarray is using the right "Z" or "M".
 */
-static int wkt_pointarray_dimensionality(POINTARRAY *pa, uint8_t flags)
+static int wkt_pointarray_dimensionality(POINTARRAY *pa, lwflags_t flags)
 {
 	int hasz = FLAGS_GET_Z(flags);
 	int hasm = FLAGS_GET_M(flags);
@@ -319,7 +319,7 @@ POINTARRAY* wkt_parser_ptarray_new(POINT p)
 */
 LWGEOM* wkt_parser_point_new(POINTARRAY *pa, char *dimensionality)
 {
-	uint8_t flags = wkt_dimensionality(dimensionality);
+	lwflags_t flags = wkt_dimensionality(dimensionality);
 	LWDEBUG(4,"entered");
 
 	/* No pointarray means it is empty */
@@ -353,7 +353,7 @@ LWGEOM* wkt_parser_point_new(POINTARRAY *pa, char *dimensionality)
 */
 LWGEOM* wkt_parser_linestring_new(POINTARRAY *pa, char *dimensionality)
 {
-	uint8_t flags = wkt_dimensionality(dimensionality);
+	lwflags_t flags = wkt_dimensionality(dimensionality);
 	LWDEBUG(4,"entered");
 
 	/* No pointarray means it is empty */
@@ -387,7 +387,7 @@ LWGEOM* wkt_parser_linestring_new(POINTARRAY *pa, char *dimensionality)
 */
 LWGEOM* wkt_parser_circularstring_new(POINTARRAY *pa, char *dimensionality)
 {
-	uint8_t flags = wkt_dimensionality(dimensionality);
+	lwflags_t flags = wkt_dimensionality(dimensionality);
 	LWDEBUG(4,"entered");
 
 	/* No pointarray means it is empty */
@@ -423,7 +423,7 @@ LWGEOM* wkt_parser_circularstring_new(POINTARRAY *pa, char *dimensionality)
 
 LWGEOM* wkt_parser_triangle_new(POINTARRAY *pa, char *dimensionality)
 {
-	uint8_t flags = wkt_dimensionality(dimensionality);
+	lwflags_t flags = wkt_dimensionality(dimensionality);
 	LWDEBUG(4,"entered");
 
 	/* No pointarray means it is empty */
@@ -534,7 +534,7 @@ LWGEOM* wkt_parser_polygon_add_ring(LWGEOM *poly, POINTARRAY *pa, char dimcheck)
 
 LWGEOM* wkt_parser_polygon_finalize(LWGEOM *poly, char *dimensionality)
 {
-	uint8_t flags = wkt_dimensionality(dimensionality);
+	lwflags_t flags = wkt_dimensionality(dimensionality);
 	int flagdims = FLAGS_NDIMS(flags);
 	LWDEBUG(4,"entered");
 
@@ -607,7 +607,7 @@ LWGEOM* wkt_parser_curvepolygon_add_ring(LWGEOM *poly, LWGEOM *ring)
 	/* Apply check for minimum number of points, if requested. */
 	if( (global_parser_result.parser_check_flags & LW_PARSER_CHECK_MINPOINTS) )
 	{
-		int vertices_needed = 3;
+		uint32_t vertices_needed = 3;
 
 		if ( ring->type == LINETYPE )
 			vertices_needed = 4;
@@ -665,7 +665,7 @@ LWGEOM* wkt_parser_curvepolygon_add_ring(LWGEOM *poly, LWGEOM *ring)
 
 LWGEOM* wkt_parser_curvepolygon_finalize(LWGEOM *poly, char *dimensionality)
 {
-	uint8_t flags = wkt_dimensionality(dimensionality);
+	lwflags_t flags = wkt_dimensionality(dimensionality);
 	int flagdims = FLAGS_NDIMS(flags);
 	LWDEBUG(4,"entered");
 
@@ -804,7 +804,7 @@ LWGEOM* wkt_parser_collection_add_geom(LWGEOM *col, LWGEOM *geom)
 
 LWGEOM* wkt_parser_collection_finalize(int lwtype, LWGEOM *geom, char *dimensionality)
 {
-	uint8_t flags = wkt_dimensionality(dimensionality);
+	lwflags_t flags = wkt_dimensionality(dimensionality);
 	int flagdims = FLAGS_NDIMS(flags);
 
 	/* No geometry means it is empty */
@@ -817,7 +817,7 @@ LWGEOM* wkt_parser_collection_finalize(int lwtype, LWGEOM *geom, char *dimension
 	if ( flagdims > 2 )
 	{
 		LWCOLLECTION *col = lwgeom_as_lwcollection(geom);
-		int i;
+		uint32_t i;
 
 		for ( i = 0 ; i < col->ngeoms; i++ )
 		{
@@ -856,7 +856,8 @@ LWGEOM* wkt_parser_collection_finalize(int lwtype, LWGEOM *geom, char *dimension
 	return geom;
 }
 
-void wkt_parser_geometry_new(LWGEOM *geom, int srid)
+void
+wkt_parser_geometry_new(LWGEOM *geom, int32_t srid)
 {
 	LWDEBUG(4,"entered");
 	LWDEBUGF(4,"geom %p",geom);
